@@ -5,12 +5,9 @@ Author: zhangkai
 Email: kai.zhang1@nio.com
 Last modified: 2018-08-10 18:13:39
 '''
-from .application import Application
-from .application import Blueprint
+from .application import Application, Blueprint
 from .basehandler import BaseHandler
 from .userhandler import bp as bp_user
-from .utils import authorized
-from .utils import cache
-from .utils import PageModule
+from .utils import PageModule, authorized, cache
 
 __all__ = ['BaseHandler', 'Application', 'Blueprint', 'bp_user', 'authorized', 'cache', 'PageModule']
