@@ -125,12 +125,11 @@ class Application(Blueprint):
 
         self.server.stop()
         self.logger.info('shutting down')
-        tasks = [task for task in asyncio.Task.all_tasks() if task is not
-                 asyncio.tasks.Task.current_task()]
-        self.logger.warning(f'canceling {len(tasks)} pending tasks')
-        if tasks:
-            asyncio.gather(*tasks, return_exceptions=True).cancel()
-
+        # tasks = [task for task in asyncio.Task.all_tasks() if task is not
+        #          asyncio.tasks.Task.current_task()]
+        # self.logger.warning(f'canceling {len(tasks)} pending tasks')
+        # if tasks:
+        #     asyncio.gather(*tasks, return_exceptions=True).cancel()
         self.ioloop.stop()
 
     def sig_handler(self, sig, frame):
