@@ -11,6 +11,7 @@ import random
 import re
 import uuid
 
+import pymongo
 import tornado.web
 from bson import ObjectId
 from utils import Dict, awaitable
@@ -169,10 +170,19 @@ class SignupHandler(BaseHandler):
             'token': token,
             'created_at': datetime.datetime.now().replace(microsecond=0)
         })
-        user = await awaitable(self.db.users.find_one_and_update({'username': doc['username']},
-                                                                 {'$set': doc},
-                                                                 upsert=True,
-                                                                 return_document=True))
+        try:
+            user = await awaitable(self.db.users.find_one_and_update({'username': doc['username']},
+                                                                     {'$set': doc},
+                                                                     upsert=True,
+                                                                     return_document=True))
+        except pymongo.errors.DuplicateKeyError:
+            seq_id = await awaitable(self.db.users.seq_id)
+            await awaitable(self.db.users.find_one_and_update({'id': {'$exists': 0}}, {'$set': {'id': seq_id}}))
+            user = await awaitable(self.db.users.find_one_and_update({'username': doc['username']},
+                                                                     {'$set': doc},
+                                                                     upsert=True,
+                                                                     return_document=True))
+
         update = {}
         if not user.id:
             update['id'] = await awaitable(self.db.users.seq_id)
@@ -294,15 +304,15 @@ class EmailHandler(BaseHandler):
             user = await self.get_user(self.args.email)
             if not user:
                 return self.finish({'err': 1, 'msg': '用户不存在'})
-            title = f'{self.request.host} 重设密码邮件'
+            title = f'{self.host} 重设密码邮件'
             code = await self.gen_code(self.args.email)
             content = f'您本次操作的验证码为: {code}'
         elif action == 'check':
-            title = f'{self.request.host} 验证邮件'
+            title = f'{self.host} 验证邮件'
             code = await self.gen_code(self.args.email)
             content = f'您本次操作的验证码为: {code}'
         elif action == 'active':
-            title = f'{self.request.host} 激活邮件'
+            title = f'{self.host} 激活邮件'
             code = uuid.uuid4().hex
             key = f'{self.prefix}_active_{code}'
             await awaitable(self.rd.setex(key, 600, self.args.email))
