@@ -5,9 +5,9 @@ import warnings
 
 from .base_utils import (AioQueue, DefaultDict, Dict, DictUnwrapper,
                          DictWrapper, JSONEncoder, Queue, Singleton, Storage,
-                         awaitable, ceil, connect, floor, get_ip, int2ip,
+                         awaitable, ceil, check_connect, floor, get_ip, int2ip,
                          int2str, ip2int, multi_apply, pprint, str2int,
-                         to_bytes, to_str, tqdm, yaml_dump, yaml_load)
+                         to_bytes, to_str, tqdm, yaml)
 from .cached_property import cached_property
 from .config_utils import Config
 from .crypto import (aes_decrypt, aes_encrypt, des_decrypt, des_encrypt,
@@ -32,9 +32,9 @@ except:
 warnings.filterwarnings("ignore")
 
 __all__ = [
-    'awaitable', 'floor', 'ceil', 'to_str', 'to_bytes', 'tqdm', 'yaml_load', 'yaml_dump', 'pprint',
+    'awaitable', 'floor', 'ceil', 'to_str', 'to_bytes', 'tqdm', 'yaml', 'pprint',
     'timeit', 'retry', 'aioretry', 'smart_decorator', 'synchronize', 'cached_property', 'multi_apply',
-    'get_ip', 'connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool', 'parse_uri',
+    'get_ip', 'check_connect', 'ip2int', 'int2ip', 'int2str', 'str2int', 'patch_connection_pool', 'parse_uri',
     'des_encrypt', 'des_decrypt', 'aes_encrypt', 'aes_decrypt', 'gen_rsa_key', 'rsa_encrypt', 'rsa_decrypt',
     'Fire', 'Ip2Region', 'Singleton', 'JSONEncoder', 'Dict', 'DefaultDict', 'DictWrapper', 'DictUnwrapper',
     'Email', 'AioEmail', 'Queue', 'AioQueue', 'Config', 'Logger', 'WatchedFileHandler', 'Storage',
