@@ -35,6 +35,33 @@ from rich.table import Table
 from tqdm import tqdm
 
 
+def _include_yaml(loader, node):
+    root = Path(loader.name).parent
+    if isinstance(node, yaml.SequenceNode):
+        return [yaml.load(open(root / x.value), Loader=yaml.FullLoader) for x in node.value]
+    else:
+        return yaml.load(open(root / node.value), Loader=yaml.FullLoader)
+
+
+def yaml_load(stream, **kwargs):
+    loader = yaml.FullLoader(stream)
+    try:
+        return DictWrapper(loader.get_single_data())
+    finally:
+        loader.dispose()
+
+
+def yaml_dump(data, stream=None, default_flow_style=False, allow_unicode=True, sort_keys=False, **kwargs):
+    return yaml.dump_all([DictUnwrapper(data)], stream, Dumper=yaml.Dumper,
+                         default_flow_style=default_flow_style,
+                         allow_unicode=allow_unicode, sort_keys=sort_keys, **kwargs)
+
+
+yaml.add_constructor('!include', _include_yaml)
+yaml.load = yaml_load
+yaml.dump = yaml_dump
+
+
 class tqdm(tqdm):
 
     def __init__(self, *args, **kwargs):
@@ -253,7 +280,7 @@ async def awaitable(ret):
 
 
 def multi_apply(func, *args, **kwargs):
-    workers = kwargs.pop('workers', os.cpu_workers())
+    workers = kwargs.pop('workers', os.cpu_count())
     pool = kwargs.pop('pool', False)
     pfunc = partial(func, **kwargs) if kwargs else func
     size = math.ceil(len(args[0]) / workers)
@@ -322,11 +349,10 @@ def get_ip(local=True):
             return get_ip()
 
 
-def connect(ip, port):
+def check_connect(ip, port):
     try:
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        s.connect((ip, port))
-        return True
+        return s.connect_ex((ip, port)) == 0
     except Exception:
         return False
     finally:
@@ -349,16 +375,6 @@ def int2str(int_time):
     return time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(int_time))
 
 
-def yaml_load(stream, **kwargs):
-    doc = yaml.load(stream, **kwargs)
-    return DictWrapper(doc)
-
-
-def yaml_dump(doc, stream=None, default_flow_style=False, allow_unicode=True, **kwargs):
-    doc = DictUnwrapper(doc)
-    return yaml.dump(doc, stream=stream, default_flow_style=default_flow_style, allow_unicode=allow_unicode, **kwargs)
-
-
 def pprint(docs, header=None, auto=False):
     console = Console()
     if auto:
@@ -366,9 +382,6 @@ def pprint(docs, header=None, auto=False):
         if not [x for x in stack if x.function == 'Fire']:
             return
 
-    if not docs:
-        return console.print(docs)
-
     if isinstance(docs, (list, tuple)):
         table = Table(show_header=True, header_style="bold magenta")
         if header is not None:
