@@ -23,7 +23,7 @@ class Config(Dict):
         for config in configs:
             self.update(self._load_cfg(config))
 
-        parser = argparse.ArgumentParser(allow_abbrev=False)
+        parser = argparse.ArgumentParser()
         parser.add_argument('--config', type=str, default=None)
         options, _ = parser.parse_known_args()
         if options.config:
@@ -75,7 +75,7 @@ class Config(Dict):
             elif isinstance(cfg.extends, str):
                 base.update(Config._load_cfg(str(root / cfg.extends)))
             base.update(cfg)
-            cfg.update(base)
+            cfg = base
 
         return cfg
 
@@ -94,6 +94,7 @@ class Config(Dict):
     def _update(opt, key, value):
         if key.find('.') >= 0:
             arr = key.split('.', 1)
+            opt.setdefault(arr[0], Dict())
             Config._update(opt[arr[0]], arr[1], value)
         else:
             if isinstance(value, list):
