@@ -323,16 +323,16 @@ class BaseRequest(metaclass=RequestMeta):
         raise NotImplementedError
 
     def _retry(self, url, kwargs, retry):
-        _kwargs = copy.deepcopy(kwargs)
-        try:
-            return self._request(url, **kwargs)
-        except Exception as e:
-            self.logger.exception(f'request failed, url: {url}, retry: {retry}, exception: {e}')
-            if retry <= 0:
-                return Response(url=url, code=599, reason=str(e))
-            else:
+        reason = 'OK'
+        for i in range(retry + 1):
+            try:
+                return self._request(url, **kwargs)
+            except Exception as e:
+                reason = str(e)
+                self.logger.error(f'url: {url}, retry: {i}, exception: {e}')
                 time.sleep(self.sleep)
-                return self._retry(url, _kwargs, retry - 1)
+
+        return Response(url=url, code=599, reason=reason)
 
     def request(self, url, **kwargs):
         raise_error = kwargs.pop('raise_error', self.raise_error)
@@ -428,16 +428,16 @@ class BaseRequest(metaclass=RequestMeta):
 class AsyncRequest(BaseRequest):
 
     async def _retry(self, url, kwargs, retry):
-        _kwargs = copy.deepcopy(kwargs)
-        try:
-            return await self._request(url, **kwargs)
-        except Exception as e:
-            self.logger.exception(f'url: {url}, retry: {retry}, exception: {e}')
-            if retry <= 0:
-                return Response(url=url, code=599, reason=str(e))
-            else:
+        reason = 'OK'
+        for i in range(retry + 1):
+            try:
+                return await self._request(url, **kwargs)
+            except Exception as e:
+                reason = str(e)
+                self.logger.error(f'url: {url}, retry: {i}, exception: {e}')
                 await asyncio.sleep(self.sleep)
-                return await self._retry(url, _kwargs, retry - 1)
+
+        return Response(url=url, code=599, reason=reason)
 
     async def _download(self, url, kwargs, fp, lock, start, end):
         kwargs = copy.deepcopy(kwargs)
